LgrLogs class abstract
Logging utilities for the Liquid Glass Renderer package.
Constructors
- LgrLogs()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deactivateLoggers(
Set< Logger> loggers) → void -
Deactivates the given
loggers. -
initAllLogs(
[Level level = Level.ALL]) → void - Initializes all the available loggers.
-
initLoggers(
Set< Logger> loggers, [Level level = Level.ALL]) → void -
Initialize the given
loggersusing the minimumlevel. -
isLogActive(
Logger logger) → bool -
Returns
trueif the givenloggeris currently logging, orfalseotherwise.