LGBottomBarExtraButton class
Configuration for the extra button in LGBottomBar.
The extra button is rendered as a LGButton and typically used for primary actions like creating new content.
Supports both IconData and custom Widget (e.g., SvgPicture) for icons.
You can use icon with either IconData or Widget, or use the explicit
iconWidget parameter.
Constructors
- LGBottomBarExtraButton({Object? icon, Widget? iconWidget, required VoidCallback onTap, required String label, double size = 64})
-
Creates an extra button configuration.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Object?
-
Icon displayed in the button.
final
- iconWidget → Widget?
-
Custom widget (e.g.,
SvgPicture) displayed in the button.final - label → String
-
Accessibility label for the button.
final
- onTap → VoidCallback
-
Callback when the button is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
Width and height of the button.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited